# Security

We take the security of Wagtail, and related packages we maintain, seriously. If you have found a security issue with any of our projects please email us at security@wagtail.org so we can work together to find and patch the issue. We appreciate responsible disclosure with any security related issues, so please contact us first before creating a Github issue.

If you want to send an encrypted email (optional), the public key ID for security@wagtail.org is [0xbed227b4daf93ff9](https://keyserver.ubuntu.com/pks/lookup?search=0xbed227b4daf93ff9&fingerprint=on&op=index), and this public key is available from most commonly-used keyservers.

This information can also be found in our security.txt: https://docs.wagtail.org/.well-known/security.txt
